@@ -2,6 +2,7 @@
 
 # Released under the MIT License.
 # Copyright, 2019-2025, by Samuel Williams.
+# Copyright, 2025, by Marc-André Cournoyer.
 
 require "etc"
 require "async/clock"
@@ -139,12 +140,18 @@ module Async
 			# Stop the children instances.
 			# @parameter timeout [Boolean | Numeric] Whether to stop gracefully, or a specific timeout.
 			def stop(timeout = true)
+				Console.info(self, "Stopping container...", timeout: timeout, caller: caller_locations)
 				@running = false
 				@group.stop(timeout)
 				
 				if @group.running?
-					Console.warn(self) {"Group is still running after stopping it!"}
+					Console.warn(self, "Group is still running after stopping it!")
+				else
+					Console.info(self, "Group has stopped.")
 				end
+			rescue => error
+				Console.error(self, "Error while stopping container!", exception: error)
+				raise
 			ensure
 				@running = true
 			end
@@ -165,7 +172,7 @@ module Async
 				name ||= UNNAMED
 				
 				if mark?(key)
-					Console.debug(self) {"Reusing existing child for #{key}: #{name}"}
+					Console.debug(self, "Reusing existing child.", child: {key: key, name: name})
 					return false
 				end
 				
@@ -173,15 +180,20 @@ module Async
 				
 				fiber do
 					while @running
-						child = self.start(name, &block)
+						Console.debug(self, "Starting child...", child: {key: key, name: name, restart: restart, health_check_timeout: health_check_timeout}, statistics: @statistics)
 						
+						child = self.start(name, &block)
 						state = insert(key, child)
 						
+						Console.debug(self, "Started child.", child: child, spawn: {key: key, restart: restart, health_check_timeout: health_check_timeout}, statistics: @statistics)
+						
 						# If a health check is specified, we will monitor the child process and terminate it if it does not update its state within the specified time.
 						if health_check_timeout
 							age_clock = state[:age] = Clock.start
 						end
 						
+						status = nil
+						
 						begin
 							status = @group.wait_for(child) do |message|
 								case message
@@ -194,15 +206,17 @@ module Async
 									age_clock&.reset!
 								end
 							end
+						rescue => error
+							Console.error(self, "Error during child process management!", exception: error, running: @running)
 						ensure
 							delete(key, child)
 						end
 						
-						if status.success?
-							Console.debug(self) {"#{child} exited with #{status}"}
+						if status&.success?
+							Console.debug(self, "Child exited successfully.", status: status, running: @running)
 						else
 							@statistics.failure!
-							Console.error(self, status: status)
+							Console.error(self, "Child exited with error!", status: status, running: @running)
 						end
 						
 						if restart
